@@ -1,4 +1,4 @@
-/* $Id: simple.c 4711 2004-11-01 16:10:55Z benny $ */
+/* $Id: simple.c 20833 2006-04-09 18:08:17Z benny $ */
 /*-
  * Copyright (c) 2003-2004 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
@@ -502,8 +502,8 @@ config_preview (XfsmSplashConfig *config)
 G_MODULE_EXPORT void
 config_init (XfsmSplashConfig *config)
 {
-  config->name        = g_strdup ("Simple");
-  config->description = g_strdup ("Simple Splash Engine");
+  config->name        = g_strdup (_("Simple"));
+  config->description = g_strdup (_("Simple Splash Engine"));
   config->version     = g_strdup (VERSION);
   config->author      = g_strdup ("Benedikt Meurer");
   config->homepage    = g_strdup ("http://www.xfce.org/");
