@@ -1,4 +1,4 @@
-/* $Id: splash.c 4711 2004-11-01 16:10:55Z benny $ */
+/* $Id: splash.c 20833 2006-04-09 18:08:17Z benny $ */
 /*-
  * Copyright (c) 2003-2004 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
@@ -367,7 +367,7 @@ splash_run (McsPlugin *plugin)
 
   /* query kiosk settings */
   kiosk = xfce_kiosk_new ("xfce4-session");
-  kiosk_can_splash = xfce_kiosk_query (kiosk, "Splash");
+  kiosk_can_splash = xfce_kiosk_query (kiosk, "Splash") || xfce_kiosk_query (kiosk, "CustomizeSplash");
   xfce_kiosk_free (kiosk);
 
   /* load config */
